@@ -22,11 +22,12 @@ https://docs.openstack.org/horizon/latest/contributor/tutorials/plugin.html
     While interactions with the service can be handled in the views.py,
     isolating the logic is an established pattern in Horizon.
 """
-
 from horizon.utils.memoized import memoized  # noqa
+import json
 from keystoneauth1.identity.generic.token import Token
 from keystoneauth1.session import Session
 from openstack_dashboard.api import base
+import tempfile
 from vitrageclient import client as vitrage_client
 
 import logging
@@ -61,9 +62,50 @@ def topology(request, query=None, graph_type='tree', all_tenants='false',
                                                limit=limit)
 
 
-def alarms(request, vitrage_id='all', all_tenants='false'):
+def alarms(request, vitrage_id='all', all_tenants='false',
+           limit=1000,
+           sort_by=['start_timestamp', 'vitrage_id'],
+           sort_dirs=['asc', 'asc'],
+           filter_by=None,
+           filter_vals=None,
+           next_page=True,
+           marker=None
+           ):
+
     return vitrageclient(request).alarm.list(vitrage_id=vitrage_id,
-                                             all_tenants=all_tenants)
+                                             all_tenants=all_tenants,
+                                             limit=limit,
+                                             sort_by=sort_by,
+                                             sort_dirs=sort_dirs,
+                                             filter_by=filter_by,
+                                             filter_vals=filter_vals,
+                                             next_page=next_page,
+                                             marker=marker
+                                             )
+
+
+def history(request, all_tenants='false',
+            start=None, end=None,
+            limit=1000,
+            sort_by=['start_timestamp', 'vitrage_id'],
+            sort_dirs=['asc', 'asc'],
+            filter_by=None,
+            filter_vals=None,
+            next_page=True,
+            marker=None
+            ):
+
+    return vitrageclient(request).alarm.history(all_tenants=all_tenants,
+                                                start=start,
+                                                end=end,
+                                                limit=limit,
+                                                sort_by=sort_by,
+                                                sort_dirs=sort_dirs,
+                                                filter_by=filter_by,
+                                                filter_vals=filter_vals,
+                                                next_page=next_page,
+                                                marker=marker
+                                                )
 
 
 def alarm_counts(request, all_tenants='false'):
@@ -77,7 +119,22 @@ def rca(request, alarm_id, all_tenants='false'):
                                           all_tenants=all_tenants)
 
 
-def templates(request, template_id='all'):
+def template_show(request, template_id='all'):
     if template_id == 'all':
         return vitrageclient(request).template.list()
     return vitrageclient(request).template.show(template_id)
+
+
+def template_delete(request, template_id):
+    return vitrageclient(request).template.delete(template_id)
+
+
+def template_add(request):
+    template = json.loads(request.body)
+    type = template.get('type')
+    with tempfile.NamedTemporaryFile(suffix='.yaml') as temp:
+        temp.write(template.get('template'))
+        temp.flush()
+        temp.seek(0)
+        response = vitrageclient(request).template.add(temp.name, type)
+    return response
